@@ -1,5 +1,5 @@
 # prime/engine/engine-alphabet.rb
-# $Id: engine-alphabet.rb,v 1.6 2004/01/09 21:45:57 komatsu Exp $
+# $Id: engine-alphabet.rb,v 1.3.2.2 2003/12/25 04:13:30 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -25,19 +25,18 @@ class PrimeEngineAlphabet < PrimeEngine
   def lookup (input, method = :prefix)
     results = PrimeResult.new
 
-    if input.original == input.original.upcase and
-        input.original != input.original.downcase then
+    if input.original == input.original.upcase then
       results << PrimeCandidate.new(input.original.downcase, input.original,
 				    17000, "̤θ") # ñ(ʸ)
     else
       results << PrimeCandidate.new(input.original.downcase, input.original,
-				    9999, "̤θ") # ñ
+				    8000, "̤θ") # ñ
     end
     ### FIXME: 㤦󥸥Ѥ.
     results << PrimeCandidate.new(input.base.downcase, input.base.katakana,
-				  9999, "̤θ") # 
+				  8000, "̤θ") # 
     results << PrimeCandidate.new(input.base.downcase, input.base,
-				  9999, "̤θ") # Ҥ餬ʤʤ
+				  8000, "̤θ") # Ҥ餬ʤʤ
     return results
   end
 end
