@@ -1,5 +1,5 @@
 # prime/engine/engine-basic.rb
-# $Id: engine-basic.rb,v 1.2 2003/12/31 09:21:24 komatsu Exp $
+# $Id: engine-basic.rb,v 1.1.1.1.2.1 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -23,36 +23,18 @@ class PrimeEngineBasic < PrimeEngineJapanese
     @id   = "basic"
     @description = "Basic engine"
 
-    initialize_posdict()
+    @partdict_file = File::join2(PRIME_DICT_DIR, 'prime-dict-pos')
+    unless File::exist?(@partdict_file) then
+      @partdict_file = File::join2(PRIME_DICT_DIR, 'prime-dict-part')
+    end
+    @partdict = Sary::Searcher.new(@partdict_file)
+
     @dict_file = File::join2(PRIME_DICT_DIR, 'prime-dict')
     @dict = Sary::Searcher.new(@dict_file)
 
     @max_candidates = 15
   end
 
-  def initialize_posdict ()
-    file_posdict  = File::join2(PRIME_DICT_DIR, 'prime-dict-pos')
-    file_partdict = File::join2(PRIME_DICT_DIR, 'prime-dict-part')
-
-    if File::exist?(file_posdict) then
-      if File::exist?(file_partdict) then
-        $stderr.puts("PRIME Warning:")
-        $stderr.puts("    Both prime-dict-pos and prime-dict-part exist")
-        $stderr.puts("    under '#{PRIME_DICT_DIR}'.")
-        $stderr.puts("    The file name 'prime-dict-part' is obsolete.")
-      end
-      @partdict_file = file_posdict
-    elsif File::exist?(file_partdict) then
-      @partdict_file = file_partdict
-    else
-      $stderr.puts("PRIME ERROR:")
-      $stderr.puts("    The POS dictionary #{file_posdict} is not found.")
-      $stderr.puts("    Please install the latest prime-dict package.")
-      Kernel::exit()
-    end
-    @partdict = Sary::Searcher.new(@partdict_file)
-  end
-
   private
   def lookup (input, method = :prefix)
     results = PrimeResult.new
