@@ -1,5 +1,5 @@
 # prime/engine/engine-basic.rb
-# $Id: engine-userdict.rb,v 1.8.2.4 2003/12/22 03:11:35 komatsu Exp $
+# $Id: engine-userdict.rb,v 1.8.2.5 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -21,12 +21,8 @@ class PrimeUserDict < Sary::Searcher
 
   def initialize (file, index_suffix = "")
     index_file = file + index_suffix + ".ary"
-    if File::file?(file) == false then
-      File::open(file, "w").close()
-    end
-    if File::file?(index_file) == false then
-      File::open(index_file, "w").close()
-    end
+    File::ensure(file,       0600)
+    File::ensure(index_file, 0600)
     super(file, index_file)
     @tmp_dict = {}
     @tmp_result = nil
@@ -126,6 +122,8 @@ class PrimeEngineUserdict < PrimeEngineJapanese
     initialize_dictbuffer()
 
     @file_index_no = File::join2(PRIME_USER_DIR, USERDICT + '_index_no')
+    File::ensure(@file_index_no, 0600)
+
     @index_no_alt_counter = 0 # This is used when $PRIME_NO_SAVE is true.
     @dict_size = @timestamps.length
 
