@@ -1,5 +1,5 @@
 # prime/prime.rb
-# $Id: prime.rb,v 1.2.2.1 2003/12/13 22:25:27 komatsu Exp $
+# $Id: prime.rb,v 1.2.2.2 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -30,6 +30,14 @@ class Prime
     local_config_file  =
       (ENV['PRIME_CONFIG'] or File::join2(PRIME_USER_DIR, 'Custom_prime.rb'))
 
+    if File::exist?(global_config_file) == false then
+      $stderr.puts "PRIME-ERROR:"
+      $stderr.puts "  The file Custom_prime.rb is not found."
+      $stderr.puts "  You might need to install Custom_prime.rb by"
+      $stderr.puts "  'make install-etc'.  Sorry for your inconvenience."
+      Kernel::exit()
+    end
+
     load(global_config_file)
     if FileTest::exist?(local_config_file) then
       load(local_config_file)
