@@ -1,5 +1,5 @@
 # session.rb
-# $Id: session.rb,v 1.1.1.1 2003/05/28 17:48:18 komatsu Exp $
+# $Id: session.rb,v 1.1.1.1.2.1 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2001 Satoru Takabayashi <satoru@namazu.org>
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
@@ -36,15 +36,17 @@ module PogemoServer
       @pogemo  = pogemo
       @name    = "no name"
       @id      = "no ID"
-      @debug = false
+      @debug   = false
       @command_table = Hash.new
       init_command_table
-
-      ## FIXME: Here is not a suitable location to open a logging file.
-      ## FIXME: <komatsu@taiyaki.org> (2003-12-16)
-      @debug_io = open(ENV['HOME'] + "/.prime/debug_" + $$.to_s + ".log", "w")
     end
-    attr_accessor :debug, :name
+    attr_accessor :name
+
+    def set_debug (filename)
+      @debug    = true
+      @debug_io = File::open(filename, "w")
+      @debug_io.chmod(0600) if @debug_io::stat.owned?
+    end
 
     def init_command_table
       add_command(:close, [], "close the connection")
@@ -113,8 +115,6 @@ module PogemoServer
     def start
       while line = @in.gets do
 	logging(line)
-#	logging(line) if @debug
-#	chunks = line.gsub(/[\r\n]/, "").split("\t+")
 	chunks = line.gsub(/[\r\n]/, "").split("\t")
 	if chunks.length > 0 then
 	  name = chunks.shift.intern
@@ -126,22 +126,29 @@ module PogemoServer
     end
 
     def logging(line)
-      line.chomp()
-      @debug_io.puts(line)
-      @debug_io.flush()
+      if @debug then
+        line.chomp()
+        @debug_io.puts(line)
+        @debug_io.flush()
+      end
     end
   end
 
   class Server
     def initialize (pogemo)
       @pogemo = pogemo
-      @debug = false
+      @debug  = false
+      @logfile = nil
     end
-    attr_accessor :debug
 
     public
     def accept
     end
+
+    def set_debug (logfile)
+      @debug   = true
+      @logfile = logfile
+    end
   end
 
   class UnixSocketServer < Server
@@ -156,7 +163,9 @@ module PogemoServer
 	t = Thread.new {
 	  s = socket
 	  session = Session.new(@pogemo, s, s)
-	  session.debug = @debug
+          if @debug then
+            session.set_debug(@logfile)
+          end
 	  session.start
 	}
 	t.abort_on_exception = true
@@ -176,7 +185,9 @@ module PogemoServer
 	t = Thread.new {
 	  s = socket
 	  session = Session.new(@pogemo, s, s)
-	  session.debug = @debug
+          if @debug then
+            session.set_debug(@logfile)
+          end
 	  session.start
 	}
 	t.abort_on_exception = true
@@ -192,7 +203,9 @@ module PogemoServer
 
     def accept
       session = Session.new(@pogemo, $stdin, $stdout)
-      session.debug = @debug
+      if @debug then
+        session.set_debug(@logfile)
+      end
       session.start
     end
   end
