@@ -1,5 +1,5 @@
 # taiyaki.rb: Ruby Libraries by Hiroyuki Komatsu
-# $Id: taiyaki.rb,v 1.2.2.1 2003/12/13 22:25:27 komatsu Exp $
+# $Id: taiyaki.rb,v 1.2.2.2 2003/12/29 09:50:35 komatsu Exp $
 #
 # Copyright (C) 2002 Hiroyuki Komatsu <komatsu@taiyaki.org>
 #     All rights reserved.
@@ -114,6 +114,15 @@ class File
     return paths.join(File::Separator)
   end
   # Check delext("text.txt")
+
+  def File::ensure (file, filemode = nil)
+    if File::file?(file) == false then
+      File::open(file, "w").close()
+    end
+    if filemode then
+      File::chmod(filemode, file)
+    end
+  end
 end
 
 class Dir
